//
// Copyright (c) 2022, MindFusion LLC - Bulgaria.
//

using System;
using System.Drawing;
using System.Windows.Forms;

using MindFusion.Diagramming;
using Pen=MindFusion.Drawing.Pen;


namespace MindFusion.Diagramming.WinForms.Samples.CS.StressTest
{
	public partial class MainForm : Form
	{
		public MainForm()
		{
			InitializeComponent();
		}

		private void btnGenerate_Click(object sender, EventArgs e)
		{
			DateTime start = DateTime.Now;

			Random r = new Random();

			// adding items is slower when the diagram is shown inside a view
			// so we create a new diagram here
			diagram = new Diagram();
			diagram.BackBrush = diagramView.Diagram.BackBrush;
			diagram.ShapeNodeStyle.Brush = diagramView.Diagram.ShapeNodeStyle.Brush;
            diagram.DiagramLinkStyle.Stroke = new MindFusion.Drawing.SolidBrush(Color.FromArgb(0, 52, 102));
			diagram.DefaultShape = Shapes.Rectangle;
			diagram.LinkHeadShape = ArrowHeads.None;
			diagram.LinkSelected += diagram_LinkSelected;
			diagram.LinkDeselected += diagram_LinkDeselected;

			// adding a lot of items is faster when these properties are set to false
			diagram.ValidityChecks = false;
			diagram.SelectAfterCreate = false;

			// this shows the new link router implemented in version 5.3
			QuickRouter router = new QuickRouter(diagram);
			router.Granularity = Granularity.CoarseGrained;
			diagram.LinkRouter = router;

			int nodes = 500;
			int links = 1000;
			try
			{
				nodes = int.Parse(tbNodes.Text);
				links = int.Parse(tbLinks.Text);
			}
			catch
			{
			}

			diagram.EnableSpatialIndex = nodes > 2500;

			for (int i = 0; i < nodes; ++i)
			{
				diagram.Factory.CreateShapeNode(r.Next(2000), r.Next(2000), 20, 10);
			}

			for (int i = 0; i < links; ++i)
			{
				diagram.Factory.CreateDiagramLink(
					diagram.Nodes[r.Next(nodes - 1)],
					diagram.Nodes[r.Next(nodes - 1)]);
			}

			if (cbRouteLinks.Checked)
				diagram.RouteAllLinks();

			TimeSpan ellapsed = DateTime.Now - start;
			lbTimeEllapsed.Text = ellapsed.ToString();

			// finally show the diagram inside the view
			diagramView.Diagram = diagram;
			diagram.Bounds = new RectangleF(0, 0, 2050, 2050);
		}

		void diagram_LinkDeselected(object sender, LinkEventArgs e)
		{
			e.Link.Pen = new Pen(Color.Black, 0);
		}

		void diagram_LinkSelected(object sender, LinkEventArgs e)
		{
			e.Link.Pen = new Pen(Color.Green, 1f);
		}
	}
}